@@ -1,9 +1,6 @@
 package Module::Build::Platform::VOS;
 
 use strict;
-use vars qw($VERSION);
-$VERSION = '0.3500_01';
-$VERSION = eval $VERSION;
 use Module::Build::Base;
 
 use vars qw(@ISA);
@@ -25,7 +22,7 @@ C<Module::Build::Base>.  Please see the L<Module::Build> for the docs.
 
 =head1 AUTHOR
 
-Ken Williams <kwilliams@cpan.org>
+Ken Williams <ken@cpan.org>
 
 =head1 SEE ALSO
 
